==> tuia-advert-center-api-1.5.9-20180715.071506-10-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertAppWhiteApplyDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.util.Date;

public class AdvertAppWhiteApplyDto {
    private Long id;

    private Long advertId;

    private String orientPkgIds;

    private Integer applyStatus;

    private String refuseReason;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getOrientPkgIds() {
        return orientPkgIds;
    }

    public void setOrientPkgIds(String orientPkgIds) {
        this.orientPkgIds = orientPkgIds == null ? null : orientPkgIds.trim();
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason == null ? null : refuseReason.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> tuia-advert-center-api-2.2.73-sources.jar: cn/com/duiba/tuia/core/api/dto/advert/AdvertAppWhiteApplyDto.java <==
package cn.com.duiba.tuia.core.api.dto.advert;

import java.io.Serializable;
import java.util.Date;

public class AdvertAppWhiteApplyDto  implements Serializable {
    private static final long serialVersionUID = 5678594825634669374L;
    private Long id;

    private Long advertId;

    private String orientPkgIds;

    private Integer applyStatus;

    private String refuseReason;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getOrientPkgIds() {
        return orientPkgIds;
    }

    public void setOrientPkgIds(String orientPkgIds) {
        this.orientPkgIds = orientPkgIds == null ? null : orientPkgIds.trim();
    }

    public Integer getApplyStatus() {
        return applyStatus;
    }

    public void setApplyStatus(Integer applyStatus) {
        this.applyStatus = applyStatus;
    }

    public String getRefuseReason() {
        return refuseReason;
    }

    public void setRefuseReason(String refuseReason) {
        this.refuseReason = refuseReason == null ? null : refuseReason.trim();
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
